@@ -3,7 +3,6 @@ import os
 import time
 import sqlite3
 
-from ..tex.path_tex import path_chapter
 from ..tex.path_tex import path_mechanics
 from ..tex.path_tex import path_electrodynamics
 from .database_functions import db_file
@@ -12,8 +11,8 @@ from .database_functions import createDatabase
 
 time_date = int(time.strftime("%H%M%S%d%m%Y"))
 
-def insertData(chapter, post_type):
-    database = create_connection(db_file(chapter, post_type))
+def insertData(chapter, post_type, format_problem):
+    database = create_connection(db_file(chapter, post_type, format_problem))
 
     cursor = database.cursor()
 
